summaryrefslogtreecommitdiffstats
path: root/kword/KWResizeTableDia.h
diff options
context:
space:
mode:
Diffstat (limited to 'kword/KWResizeTableDia.h')
-rw-r--r--kword/KWResizeTableDia.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/kword/KWResizeTableDia.h b/kword/KWResizeTableDia.h
index 162afb77..f1512269 100644
--- a/kword/KWResizeTableDia.h
+++ b/kword/KWResizeTableDia.h
@@ -25,8 +25,8 @@
class KWTableFrameSet;
class KWDocument;
-class QWidget;
-class QSpinBox;
+class TQWidget;
+class TQSpinBox;
class KoUnitDoubleSpinBox;
/**
@@ -35,20 +35,21 @@ class KoUnitDoubleSpinBox;
class KWResizeTableDia : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
* @param parent parent widget for dialog
* @param table the table to do the resizes on
* @param doc the document this table belongs to, for undo information
* @param resizeColumn the initial column that the user can resize.
*/
- KWResizeTableDia( QWidget *parent, KWTableFrameSet *table, KWDocument *doc, int resizeColumn);
+ KWResizeTableDia( TQWidget *tqparent, KWTableFrameSet *table, KWDocument *doc, int resizeColumn);
protected:
void setupTab1( int resizeColumn);
bool doResize();
- QSpinBox *m_value;
+ TQSpinBox *m_value;
KWTableFrameSet *m_table;
KWDocument *m_doc;
KoUnitDoubleSpinBox *m_position;
@@ -35,20 +35,21 @@ class KoUnitDoubleSpinBox;
/**
* Constructor.
- * @param parent parent widget for dialog
+ * @param tqparent tqparent widget for dialog
* @param table the table to do the resizes on
* @param doc the document this table belongs to, for undo information